class ExtensionMixin:
    def __init__(self):
        self.name = "Unknown"
        self.author = "Unknown"
        self.id = "N/A"


    def get_dependencies(self):
        """
            Overwrite this method to make your own dependencies.
        """

        return {
            "hard": [],
            "soft": []
        }


    def mixin(_, class_to_patch: object, class_to_mix_in: object):
        """
            A boilerplate function for mixing.
            
            This sets/overwrites attributes of `class_to_patch` to attributes of
            `class_to_mix_in` (monkey-patch).
        """

        for prop, value in vars(class_to_mix_in).items():
            if not prop.startswith('__'):
                setattr(class_to_patch, f'{prop}', value)


from .flarum.Flarum_Approval import ApprovalDiscussionNotificationMixin, ApprovalExtension
from .flarum.FoF_BestAnswer import BestAnswerDiscussionMixin, BestAnswerExtension


if __name__ == '__main__':
    print(
        ApprovalDiscussionNotificationMixin, ApprovalExtension,
        BestAnswerDiscussionMixin, BestAnswerExtension
    )



# -*- coding: utf-8 -*-

"""
    pyFlarum Python package - provides an easy access to Flarum's API.

    (c) Kevo 2021

    You are allowed to modify any parts of this program, as long as this
    notice stays on its place, without any modifications. It is that simple
    to support my hard work. Thank you for using this.

    - PyPi: https://pypi.org/project/pyFlarum/
    - Official Flarum website: https://flarum.org
"""


from .session import FlarumUser
from .error_handler import FlarumError

from .flarum.core.discussions import Discussion

from .flarum.core.filters import Filter


__description__ = "An unofficial Python package for manipulating with Flarum's API"
__author__      = "SKevo"
__copyright__   = "Copyright 2021, SKevo"
__credits__     = ["SKevo"]
__license__     = "GPLv3"
__version__     = "v1.0.0-beta"
__maintainer__  = "SKevo"
__email__       = "me@kevo.link"
__status__      = "4 - Beta"


if __name__ == '__main__':
    print(
        FlarumUser,
        FlarumError,
        
        Discussion,

        Filter,
    )
